@@ -132,6 +132,7 @@ class BaseRun(DataMixin, models.Model):
         default=False,
         help_text="Automatically add new players to new instances for runs in play.",
     )
+    date_continuous_end = models.DateTimeField(blank=True, null=True)
 
     date_prepare = None
 
@@ -208,8 +209,10 @@ class BaseRun(DataMixin, models.Model):
         with transaction.atomic():
             if self.multiplayer:
                 lobby: Lobby
-                for lobby in self.lobby_set.ready():
-                    instance, created = self.create_multiplayer_instance_from_lobby(lobby)
+                for lobby in self.lobby_set.ready(include_linked=True):
+                    instance, created = self.create_multiplayer_instance_from_lobby(
+                        lobby
+                    )
                     if created:
                         instances.append(instance)
             else:
@@ -234,11 +237,19 @@ class BaseRun(DataMixin, models.Model):
         player.save()
 
     def get_or_create_multiplayer_instance(
-        self, lobby: Lobby
+        self, lobby: Lobby, defaults: dict = None
     ) -> Tuple[BaseInstance, bool]:
-        return get_instance_model()._default_manager.get_or_create(
-            run=self, game=self.game, name=lobby.name
+        defaults = defaults or {}
+        if not "name" in defaults:
+            defaults["name"] = lobby.name
+        defaults["game"] = self.game
+        instance, created = get_instance_model()._default_manager.get_or_create(
+            run=self, lobby=lobby, defaults=defaults
         )
+        if created:
+            lobby.instance = instance
+            lobby.save()
+        return instance, created
 
     def create_singleplayer_instance(self, player: BasePlayer) -> BaseInstance:
         instance = get_instance_model()._default_manager.create(
@@ -258,11 +269,28 @@ class BaseRun(DataMixin, models.Model):
         return started
 
     @property
-    def continuous_configurable(self):
+    def continuous_configurable(self) -> bool:
         if self.game:
             return self.game.continuous is None
         return apps.get_app_config("simpl").CONTINUOUS_CONFIGURABLE
 
+    @property
+    def continuous_open(self) -> bool:
+        """
+        Whether the run is open for continuous runs.
+
+        The run must be marked as continuous, in Play status, and without a
+        date_continous_end in the past.
+        """
+        return (
+            self.status == self.STATUS.PLAY
+            and self.continuous
+            and (
+                not self.date_continuous_end
+                or self.date_continuous_end > timezone.now()
+            )
+        )
+
 
 class Run(BaseRun, DataMixin, models.Model):
     """
@@ -412,6 +440,9 @@ class Lobby(models.Model):
     run: BaseRun = models.ForeignKey(settings.SIMPL_RUN, on_delete=models.CASCADE)
     name = models.CharField(max_length=100)
     date_created = models.DateTimeField(editable=False, default=timezone.now)
+    instance: Instance = models.ForeignKey(
+        settings.SIMPL_INSTANCE, on_delete=models.SET_NULL, blank=True, null=True
+    )
 
     objects = managers.LobbyQuerySet.as_manager()
 
@@ -426,8 +457,15 @@ class Lobby(models.Model):
     player_set: Player.PlayerRelatedManager
 
     @cached_property
-    def ready(self):
-        return Lobby.objects.prepare_ready().get(pk=self.pk).ready
+    def ready(self) -> Optional[bool]:
+        if self.instance_id:
+            return None  # Not ready because linked to an instance already.
+        obj = Lobby.objects.prepare_ready().get(pk=self.pk)
+        if obj.ready:
+            return True
+        if not obj.player_count:
+            return None  # Not ready because there are no players.
+        return False
 
 
 class BasePlayer(models.Model):
